@@ -1,7 +1,4 @@
-from typing import List, Tuple
-
-import requests
-from bs4 import BeautifulSoup
+import datetime
 
 from .source import Source
 from ...models import Chapter, Novel, Metadata
@@ -10,42 +7,33 @@ from ...models import Chapter, Novel, Metadata
 class NovelsRock(Source):
     name = 'Novels Rock'
     base_urls = ('https://novelsrock.com',)
+    last_updated = datetime.date(2021, 9, 4)
 
-    def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
+    def novel(self, url: str) -> Novel:
         soup = self.get_soup(url)
-        metadata = []
 
         novel = Novel(
             title=soup.select_one('.breadcrumb > li:last-child').text.strip(),
             author=', '.join([a.text.strip() for a in soup.select('.author-content > a')]),
             thumbnail_url=soup.select_one('.summary_image img')['src'],
-            synopsis='\n'.join([p.text.strip() for p in soup.select('.summary__content')]),
+            synopsis=[str(p).strip() for p in soup.select_one('.summary__content').find_all(text=True, recursive=False)],
             url=url,
         )
 
         for a in soup.select('.summary_content_wrap a[href*="genre"]'):
-            metadata.append(Metadata('subject', a.text.strip()))
+            novel.metadata.append(Metadata('subject', a.text.strip()))
 
-        novel_id = soup.select_one('.wp-manga-action-button[data-action=bookmark]')['data-post']
-
-        response = requests.post('https://novelsrock.com/wp-admin/admin-ajax.php', data={
-            'action': 'manga_get_chapters',
-            'manga': int(novel_id)
-        })
-
-        soup = BeautifulSoup(response.content, 'lxml')
-
-        chapters = []
+        volume = novel.get_default_volume()
         for a in reversed(soup.select('.wp-manga-chapter > a')):
             chapter = Chapter(
-                index=len(chapters),
+                index=len(volume.chapters),
                 title=a.text.strip(),
                 url=a['href'],
             )
 
-            chapters.append(chapter)
+            volume.chapters.append(chapter)
 
-        return novel, chapters, metadata
+        return novel
 
     def chapter(self, chapter: Chapter):
         soup = self.get_soup(chapter.url)
