@@ -1,6 +1,6 @@
 import re
-from abc import ABC, abstractmethod
-from typing import Tuple, Union
+from abc import abstractmethod
+from typing import Tuple, Union, List
 from urllib.parse import urlparse
 
 from requests.cookies import RequestsCookieJar
@@ -10,7 +10,7 @@ from ...exceptions import UnavailableException
 from ...models import Novel, Chapter
 
 
-class Source(Crawler, ABC):
+class Source(Crawler):
     name: str
     lang = 'en'
     login_viable: bool = False
@@ -41,16 +41,12 @@ class Source(Crawler, ABC):
         """Login to the source and assign the required cookies"""
         raise UnavailableException(f"'{self.__name__}' scraper does not provide login functionality.")
 
-    def search(self, keyword: str, *args, **kwargs):
+    def search(self, keyword: str, *args, **kwargs) -> List[Novel]:
         """Search for a novel on the source"""
         raise UnavailableException(f"'{self.__name__}' scraper does not provide search functionality.")
 
     def set_cookies(self, cookies: Union[RequestsCookieJar, Tuple[dict]]):
-        """
-        Replaces current cookiejar with given cookies
-
-        :param cookies: new cookiejar
-        """
+        """Replaces current cookiejar with given cookies"""
         if type(cookies) == RequestsCookieJar:
             super(Source, self).set_cookies(cookies)
         elif type(cookies) == tuple:
